@@ -14,15 +14,15 @@ foreign import ccall "add_all_int8"
 
 main :: IO ()
 main = do
-    let a = narrowInt8# 0#
-        b = narrowInt8# 1#
-        c = narrowInt8# 2#
-        d = narrowInt8# 3#
-        e = narrowInt8# 4#
-        f = narrowInt8# 5#
-        g = narrowInt8# 6#
-        h = narrowInt8# 7#
-        i = narrowInt8# 8#
-        j = narrowInt8# 9#
-        x = I# (extendInt8# (add_all_int8 a b c d e f g h i j))
+    let a = intToInt8# 0#
+        b = intToInt8# 1#
+        c = intToInt8# 2#
+        d = intToInt8# 3#
+        e = intToInt8# 4#
+        f = intToInt8# 5#
+        g = intToInt8# 6#
+        h = intToInt8# 7#
+        i = intToInt8# 8#
+        j = intToInt8# 9#
+        x = I# (int8ToInt# (add_all_int8 a b c d e f g h i j))
     print x
