@@ -1,7 +1,7 @@
 {-# Language DeriveGeneric, MagicHash #-}
 
 import GHC.Generics
-import GHC.Prim
+import GHC.Exts
 
 data Array a = Array (Array# a) deriving Generic1
 newtype Vec a = MkVec {unVec :: Array a} deriving Generic1
