@@ -1,4 +1,4 @@
--- Control.Monad.Except re-exports Control.Monad.Fix.
+-- Control.Monad re-exports Control.Monad.Fail.
 -- This test checks that the subordinate-name test
 -- for a class operation (when renaming the instance decl)
 -- works correctly.
@@ -6,7 +6,6 @@
 module ShouldCompile where
 
 import Control.Monad
-import Control.Monad.Except
 
 data Foo a = Foo a
 
@@ -21,5 +20,5 @@ instance Monad Foo where
   return         = pure
   (Foo a) >>= k  = k a
 
-instance MonadFix Foo where
-         mfix = undefined
+instance MonadFail Foo where
+         fail = undefined
